==> webkit2gtk_2.46.4.orig.tar.xz: webkitgtk-2.46.4/Source/WebKit/WebProcess/Plugins/PDF/PDFPluginChoiceAnnotation.h <==
/*
 * Copyright (C) 2012-2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(PDF_PLUGIN) && PLATFORM(MAC)

#include "PDFPluginAnnotation.h"

namespace WebCore {
class Element;
}

OBJC_CLASS PDFAnnotationChoiceWidget;

namespace WebKit {

class PDFPluginChoiceAnnotation : public PDFPluginAnnotation {
public:
    static Ref<PDFPluginChoiceAnnotation> create(PDFAnnotation *, PDFPluginBase*);

    void updateGeometry() override;
    void commit() override;

private:
    PDFPluginChoiceAnnotation(PDFAnnotation *annotation, PDFPluginBase* plugin)
        : PDFPluginAnnotation(annotation, plugin)
    {
    }

    Ref<WebCore::Element> createAnnotationElement() override;

ALLOW_DEPRECATED_DECLARATIONS_BEGIN
    PDFAnnotationChoiceWidget *choiceAnnotation() { return static_cast<PDFAnnotationChoiceWidget *>(annotation()); }
ALLOW_DEPRECATED_DECLARATIONS_END
};

} // namespace WebKit

#endif // ENABLE(PDF_PLUGIN) && PLATFORM(MAC)

==> webkit2gtk_2.48.6.orig.tar.xz: webkitgtk-2.48.6/Source/WebKit/WebProcess/Plugins/PDF/PDFPluginChoiceAnnotation.h <==
/*
 * Copyright (C) 2012-2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(PDF_PLUGIN) && PLATFORM(MAC)

#include "PDFPluginAnnotation.h"

namespace WebCore {
class Element;
}

namespace WebKit {

class PDFPluginChoiceAnnotation : public PDFPluginAnnotation {
    WTF_MAKE_FAST_ALLOCATED;
    WTF_OVERRIDE_DELETE_FOR_CHECKED_PTR(PDFPluginChoiceAnnotation);
public:
    static Ref<PDFPluginChoiceAnnotation> create(PDFAnnotation *, PDFPluginBase*);

    void updateGeometry() override;
    void commit() override;

private:
    PDFPluginChoiceAnnotation(PDFAnnotation *annotation, PDFPluginBase* plugin)
        : PDFPluginAnnotation(annotation, plugin)
    {
    }

    Ref<WebCore::Element> createAnnotationElement() override;
};

} // namespace WebKit

#endif // ENABLE(PDF_PLUGIN) && PLATFORM(MAC)
